#[non_exhaustive]pub enum State {
Unspecified,
Creating,
Ready,
Updating,
Deleting,
Repairing,
PerformingMaintenance,
Unavailable,
UnknownValue(UnknownValue),
}Expand description
Represents the different states of a managed domain.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Not set.
Creating
The domain is being created.
Ready
The domain has been created and is fully usable.
Updating
The domain’s configuration is being updated.
Deleting
The domain is being deleted.
Repairing
The domain is being repaired and may be unusable. Details
can be found in the status_message field.
PerformingMaintenance
The domain is undergoing maintenance.
The domain is not serving requests.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using State::value or State::name.
Implementations