#[non_exhaustive]pub struct CreateMicrosoftAdDomainRequest {
pub parent: String,
pub domain_name: String,
pub domain: Option<Domain>,
/* private fields */
}Expand description
Request message for [CreateMicrosoftAdDomain][google.cloud.managedidentities.v1.CreateMicrosoftAdDomain]
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource project name and location using the form:
projects/{project_id}/locations/global
domain_name: StringRequired. The fully qualified domain name. e.g. mydomain.myorganization.com, with the following restrictions:
- Must contain only lowercase letters, numbers, periods and hyphens.
- Must start with a letter.
- Must contain between 2-64 characters.
- Must end with a number or a letter.
- Must not start with period.
- First segement length (mydomain form example above) shouldn’t exceed 15 chars.
- The last segment cannot be fully numeric.
- Must be unique within the customer project.
domain: Option<Domain>Required. A Managed Identity domain resource.
Implementations
Sourceimpl CreateMicrosoftAdDomainRequest
impl CreateMicrosoftAdDomainRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_domain_name<T: Into<String>>(self, v: T) -> Self
pub fn set_domain_name<T: Into<String>>(self, v: T) -> Self
Sets the value of domain_name.
Example
ⓘ
let x = CreateMicrosoftAdDomainRequest::new().set_domain_name("example");Sourcepub fn set_domain<T>(self, v: T) -> Self
pub fn set_domain<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_domain<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_domain<T>(self, v: Option<T>) -> Self