#[non_exhaustive]pub struct Domain {
pub name: String,
pub labels: HashMap<String, String>,
pub authorized_networks: Vec<String>,
pub reserved_ip_range: String,
pub locations: Vec<String>,
pub admin: String,
pub fqdn: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub state: State,
pub status_message: String,
pub trusts: Vec<Trust>,
/* private fields */
}Expand description
Represents a managed Microsoft Active Directory domain.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The unique name of the domain using the form:
projects/{project_id}/locations/global/domains/{domain_name}.
labels: HashMap<String, String>Optional. Resource labels that can contain user-provided metadata.
Optional. The full names of the Google Compute Engine
networks the domain
instance is connected to. Networks can be added using UpdateDomain.
The domain is only available on networks listed in authorized_networks.
If CIDR subnets overlap between networks, domain creation will fail.
reserved_ip_range: StringRequired. The CIDR range of internal addresses that are reserved for this domain. Reserved networks must be /24 or larger. Ranges must be unique and non-overlapping with existing subnets in Domain.[authorized_networks].
locations: Vec<String>Required. Locations where domain needs to be provisioned. [regions][compute/docs/regions-zones/] e.g. us-west1 or us-east4 Service supports up to 4 locations at once. Each location will use a /26 block.
admin: StringOptional. The name of delegated administrator account used to perform
Active Directory operations. If not specified, setupadmin will be used.
fqdn: StringOutput only. The fully-qualified domain name of the exposed domain used by clients to connect to the service. Similar to what would be chosen for an Active Directory set up on an internal network.
create_time: Option<Timestamp>Output only. The time the instance was created.
update_time: Option<Timestamp>Output only. The last update time.
state: StateOutput only. The current state of this domain.
status_message: StringOutput only. Additional information about the current status of this domain, if available.
trusts: Vec<Trust>Output only. The current trusts associated with the domain.
Implementations
Sourceimpl Domain
impl Domain
pub fn new() -> Self
Sourcepub fn set_labels<T, K, V>(self, v: T) -> Self
pub fn set_labels<T, K, V>(self, v: T) -> Self
Sets the value of authorized_networks.
Example
let x = Domain::new().set_authorized_networks(["a", "b", "c"]);Sourcepub fn set_reserved_ip_range<T: Into<String>>(self, v: T) -> Self
pub fn set_reserved_ip_range<T: Into<String>>(self, v: T) -> Self
Sets the value of reserved_ip_range.
Example
let x = Domain::new().set_reserved_ip_range("example");Sourcepub fn set_locations<T, V>(self, v: T) -> Self
pub fn set_locations<T, V>(self, v: T) -> Self
Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Domain::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Domain::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Domain::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Domain::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Domain::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Domain::new().set_or_clear_update_time(None::<Timestamp>);