#[non_exhaustive]pub struct ListDomainsRequest {
pub parent: String,
pub page_size: i32,
pub page_token: String,
pub filter: String,
pub order_by: String,
/* private fields */
}Expand description
Request message for [ListDomains][google.cloud.managedidentities.v1.ListDomains]
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.parent: StringRequired. The resource name of the domain location using the form:
projects/{project_id}/locations/global
page_size: i32Optional. The maximum number of items to return. If not specified, a default value of 1000 will be used. Regardless of the page_size value, the response may include a partial list. Callers should rely on a response’s next_page_token to determine if there are additional results to list.
page_token: StringOptional. The next_page_token value returned from a previous ListDomainsRequest
request, if any.
filter: StringOptional. A filter specifying constraints of a list operation.
For example, Domain.fqdn="mydomain.myorginization".
order_by: StringOptional. Specifies the ordering of results. See Sorting order for more information.
Implementations
Sourceimpl ListDomainsRequest
impl ListDomainsRequest
pub fn new() -> Self
Sourcepub fn set_parent<T: Into<String>>(self, v: T) -> Self
pub fn set_parent<T: Into<String>>(self, v: T) -> Self
Sourcepub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
pub fn set_page_size<T: Into<i32>>(self, v: T) -> Self
Sourcepub fn set_page_token<T: Into<String>>(self, v: T) -> Self
pub fn set_page_token<T: Into<String>>(self, v: T) -> Self
Sets the value of page_token.
Example
let x = ListDomainsRequest::new().set_page_token("example");Sourcepub fn set_filter<T: Into<String>>(self, v: T) -> Self
pub fn set_filter<T: Into<String>>(self, v: T) -> Self