#[non_exhaustive]pub struct ReconfigureTrustRequest {
pub name: String,
pub target_domain_name: String,
pub target_dns_ip_addresses: Vec<String>,
/* private fields */
}Expand description
Request message for [ReconfigureTrust][google.cloud.managedidentities.v1.ReconfigureTrust]
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.name: StringRequired. The resource domain name, project name and location using the form:
projects/{project_id}/locations/global/domains/{domain_name}
target_domain_name: StringRequired. The fully-qualified target domain name which will be in trust with current domain.
target_dns_ip_addresses: Vec<String>Required. The target DNS server IP addresses to resolve the remote domain involved in the trust.
Implementations
Sourceimpl ReconfigureTrustRequest
impl ReconfigureTrustRequest
pub fn new() -> Self
Sourcepub fn set_target_domain_name<T: Into<String>>(self, v: T) -> Self
pub fn set_target_domain_name<T: Into<String>>(self, v: T) -> Self
Sets the value of target_domain_name.
Example
ⓘ
let x = ReconfigureTrustRequest::new().set_target_domain_name("example");Sourcepub fn set_target_dns_ip_addresses<T, V>(self, v: T) -> Self
pub fn set_target_dns_ip_addresses<T, V>(self, v: T) -> Self
Sets the value of target_dns_ip_addresses.
Example
ⓘ
let x = ReconfigureTrustRequest::new().set_target_dns_ip_addresses(["a", "b", "c"]);Trait Implementations
Sourceimpl Clone for ReconfigureTrustRequest
impl Clone for ReconfigureTrustRequest
Sourcefn clone(&self) -> ReconfigureTrustRequest
fn clone(&self) -> ReconfigureTrustRequest
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ReconfigureTrustRequest
impl Debug for ReconfigureTrustRequest
Sourceimpl Default for ReconfigureTrustRequest
impl Default for ReconfigureTrustRequest
Sourcefn default() -> ReconfigureTrustRequest
fn default() -> ReconfigureTrustRequest
Returns the “default value” for a type. Read more
Sourceimpl Message for ReconfigureTrustRequest
impl Message for ReconfigureTrustRequest
Sourceimpl PartialEq for ReconfigureTrustRequest
impl PartialEq for ReconfigureTrustRequest
impl StructuralPartialEq for ReconfigureTrustRequest