#[non_exhaustive]pub struct Trust {
pub target_domain_name: String,
pub trust_type: TrustType,
pub trust_direction: TrustDirection,
pub selective_authentication: bool,
pub target_dns_ip_addresses: Vec<String>,
pub trust_handshake_secret: String,
pub create_time: Option<Timestamp>,
pub update_time: Option<Timestamp>,
pub state: State,
pub state_description: String,
pub last_trust_heartbeat_time: Option<Timestamp>,
/* private fields */
}Expand description
Represents a relationship between two domains. This allows a controller in one domain to authenticate a user in another domain.
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.target_domain_name: StringRequired. The fully qualified target domain name which will be in trust with the current domain.
trust_type: TrustTypeRequired. The type of trust represented by the trust resource.
trust_direction: TrustDirectionRequired. The trust direction, which decides if the current domain is trusted, trusting, or both.
selective_authentication: boolOptional. The trust authentication type, which decides whether the trusted side has forest/domain wide access or selective access to an approved set of resources.
target_dns_ip_addresses: Vec<String>Required. The target DNS server IP addresses which can resolve the remote domain involved in the trust.
trust_handshake_secret: StringRequired. The trust secret used for the handshake with the target domain. This will not be stored.
create_time: Option<Timestamp>Output only. The time the instance was created.
update_time: Option<Timestamp>Output only. The last update time.
state: StateOutput only. The current state of the trust.
state_description: StringOutput only. Additional information about the current state of the trust, if available.
last_trust_heartbeat_time: Option<Timestamp>Output only. The last heartbeat time when the trust was known to be connected.
Implementations
Sourceimpl Trust
impl Trust
pub fn new() -> Self
Sourcepub fn set_target_domain_name<T: Into<String>>(self, v: T) -> Self
pub fn set_target_domain_name<T: Into<String>>(self, v: T) -> Self
Sets the value of target_domain_name.
Example
let x = Trust::new().set_target_domain_name("example");Sourcepub fn set_trust_type<T: Into<TrustType>>(self, v: T) -> Self
pub fn set_trust_type<T: Into<TrustType>>(self, v: T) -> Self
Sets the value of trust_type.
Example
use google_cloud_managedidentities_v1::model::trust::TrustType;
let x0 = Trust::new().set_trust_type(TrustType::Forest);
let x1 = Trust::new().set_trust_type(TrustType::External);Sourcepub fn set_trust_direction<T: Into<TrustDirection>>(self, v: T) -> Self
pub fn set_trust_direction<T: Into<TrustDirection>>(self, v: T) -> Self
Sets the value of trust_direction.
Example
use google_cloud_managedidentities_v1::model::trust::TrustDirection;
let x0 = Trust::new().set_trust_direction(TrustDirection::Inbound);
let x1 = Trust::new().set_trust_direction(TrustDirection::Outbound);
let x2 = Trust::new().set_trust_direction(TrustDirection::Bidirectional);Sourcepub fn set_selective_authentication<T: Into<bool>>(self, v: T) -> Self
pub fn set_selective_authentication<T: Into<bool>>(self, v: T) -> Self
Sets the value of selective_authentication.
Example
let x = Trust::new().set_selective_authentication(true);Sourcepub fn set_target_dns_ip_addresses<T, V>(self, v: T) -> Self
pub fn set_target_dns_ip_addresses<T, V>(self, v: T) -> Self
Sets the value of target_dns_ip_addresses.
Example
let x = Trust::new().set_target_dns_ip_addresses(["a", "b", "c"]);Sourcepub fn set_trust_handshake_secret<T: Into<String>>(self, v: T) -> Self
pub fn set_trust_handshake_secret<T: Into<String>>(self, v: T) -> Self
Sets the value of trust_handshake_secret.
Example
let x = Trust::new().set_trust_handshake_secret("example");Sourcepub fn set_create_time<T>(self, v: T) -> Self
pub fn set_create_time<T>(self, v: T) -> Self
Sets the value of create_time.
Example
use wkt::Timestamp;
let x = Trust::new().set_create_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of create_time.
Example
use wkt::Timestamp;
let x = Trust::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Trust::new().set_or_clear_create_time(None::<Timestamp>);Sourcepub fn set_update_time<T>(self, v: T) -> Self
pub fn set_update_time<T>(self, v: T) -> Self
Sets the value of update_time.
Example
use wkt::Timestamp;
let x = Trust::new().set_update_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_time.
Example
use wkt::Timestamp;
let x = Trust::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Trust::new().set_or_clear_update_time(None::<Timestamp>);Sourcepub fn set_state_description<T: Into<String>>(self, v: T) -> Self
pub fn set_state_description<T: Into<String>>(self, v: T) -> Self
Sets the value of state_description.
Example
let x = Trust::new().set_state_description("example");Sourcepub fn set_last_trust_heartbeat_time<T>(self, v: T) -> Self
pub fn set_last_trust_heartbeat_time<T>(self, v: T) -> Self
Sets the value of last_trust_heartbeat_time.
Example
use wkt::Timestamp;
let x = Trust::new().set_last_trust_heartbeat_time(Timestamp::default()/* use setters */);Sourcepub fn set_or_clear_last_trust_heartbeat_time<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_last_trust_heartbeat_time<T>(self, v: Option<T>) -> Self
Sets or clears the value of last_trust_heartbeat_time.
Example
use wkt::Timestamp;
let x = Trust::new().set_or_clear_last_trust_heartbeat_time(Some(Timestamp::default()/* use setters */));
let x = Trust::new().set_or_clear_last_trust_heartbeat_time(None::<Timestamp>);