#[non_exhaustive]pub struct UpdateDomainRequest {
pub update_mask: Option<FieldMask>,
pub domain: Option<Domain>,
/* private fields */
}Expand description
Request message for [UpdateDomain][google.cloud.managedidentities.v1.UpdateDomain]
Fields (Non-exhaustive)
This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional
Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.update_mask: Option<FieldMask>Required. Mask of fields to update. At least one path must be supplied in this field. The elements of the repeated paths field may only include fields from Domain:
labelslocationsauthorized_networks
domain: Option<Domain>Required. Domain message with updated fields. Only supported fields specified in update_mask are updated.
Implementations
Sourceimpl UpdateDomainRequest
impl UpdateDomainRequest
pub fn new() -> Self
Sourcepub fn set_update_mask<T>(self, v: T) -> Self
pub fn set_update_mask<T>(self, v: T) -> Self
Sets the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateDomainRequest::new().set_update_mask(FieldMask::default()/* use setters */);Sourcepub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_update_mask<T>(self, v: Option<T>) -> Self
Sets or clears the value of update_mask.
Example
ⓘ
use wkt::FieldMask;
let x = UpdateDomainRequest::new().set_or_clear_update_mask(Some(FieldMask::default()/* use setters */));
let x = UpdateDomainRequest::new().set_or_clear_update_mask(None::<FieldMask>);Sourcepub fn set_domain<T>(self, v: T) -> Self
pub fn set_domain<T>(self, v: T) -> Self
Sourcepub fn set_or_clear_domain<T>(self, v: Option<T>) -> Self
pub fn set_or_clear_domain<T>(self, v: Option<T>) -> Self