#[non_exhaustive]pub enum TrustDirection {
Unspecified,
Inbound,
Outbound,
Bidirectional,
UnknownValue(UnknownValue),
}Expand description
Represents the direction of trust. See System.DirectoryServices.ActiveDirectory.TrustDirection for more information.
Working with unknown values
This enum is defined as #[non_exhaustive] because Google Cloud may add
additional enum variants at any time. Adding new variants is not considered
a breaking change. Applications should write their code in anticipation of:
- New values appearing in future releases of the client library, and
- New values received dynamically, without application changes.
Please consult the Working with enums section in the user guide for some guidelines.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Unspecified
Not set.
Inbound
The inbound direction represents the trusting side.
Outbound
The outboud direction represents the trusted side.
Bidirectional
The bidirectional direction represents the trusted / trusting side.
UnknownValue(UnknownValue)
If set, the enum was initialized with an unknown value.
Applications can examine the value using TrustDirection::value or TrustDirection::name.
Implementations