Domain

Struct Domain 

#[non_exhaustive]
pub struct Domain { pub name: String, pub labels: HashMap<String, String>, pub authorized_networks: Vec<String>, pub reserved_ip_range: String, pub locations: Vec<String>, pub admin: String, pub fqdn: String, pub create_time: Option<Timestamp>, pub update_time: Option<Timestamp>, pub state: State, pub status_message: String, pub trusts: Vec<Trust>, /* private fields */ }
Represents a managed Microsoft Active Directory domain.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
name: String

Required. The unique name of the domain using the form: projects/{project_id}/locations/global/domains/{domain_name}.

labels: HashMap<String, String>

Optional. Resource labels that can contain user-provided metadata.

authorized_networks: Vec<String>

Optional. The full names of the Google Compute Engine networks the domain instance is connected to. Networks can be added using UpdateDomain. The domain is only available on networks listed in authorized_networks. If CIDR subnets overlap between networks, domain creation will fail.

reserved_ip_range: String

Required. The CIDR range of internal addresses that are reserved for this domain. Reserved networks must be /24 or larger. Ranges must be unique and non-overlapping with existing subnets in Domain.[authorized_networks].

locations: Vec<String>

Required. Locations where domain needs to be provisioned. [regions][compute/docs/regions-zones/] e.g. us-west1 or us-east4 Service supports up to 4 locations at once. Each location will use a /26 block.

admin: String

Optional. The name of delegated administrator account used to perform Active Directory operations. If not specified, setupadmin will be used.

fqdn: String

Output only. The fully-qualified domain name of the exposed domain used by clients to connect to the service. Similar to what would be chosen for an Active Directory set up on an internal network.

create_time: Option<Timestamp>

Output only. The time the instance was created.

update_time: Option<Timestamp>

Output only. The last update time.

state: State

Output only. The current state of this domain.

status_message: String

Output only. Additional information about the current status of this domain, if available.

trusts: Vec<Trust>

Output only. The current trusts associated with the domain.

Implementations

Source

impl Domain

pub fn new() -> Self

pub fn set_name<T: Into<String>>(self, v: T) -> Self

Sets the value of name.

Example
let x = Domain::new().set_name("example");
pub fn set_labels<T, K, V>(self, v: T) -> Self
where T: IntoIterator<Item = (K, V)>, K: Into<String>, V: Into<String>,

Sets the value of labels.

Example
let x = Domain::new().set_labels([
    ("key0", "abc"),
    ("key1", "xyz"),
]);
pub fn set_authorized_networks<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of authorized_networks.

Example
let x = Domain::new().set_authorized_networks(["a", "b", "c"]);
pub fn set_reserved_ip_range<T: Into<String>>(self, v: T) -> Self

Sets the value of reserved_ip_range.

Example
let x = Domain::new().set_reserved_ip_range("example");
pub fn set_locations<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<String>,

Sets the value of locations.

Example
let x = Domain::new().set_locations(["a", "b", "c"]);
pub fn set_admin<T: Into<String>>(self, v: T) -> Self

Sets the value of admin.

Example
let x = Domain::new().set_admin("example");
pub fn set_fqdn<T: Into<String>>(self, v: T) -> Self

Sets the value of fqdn.

Example
let x = Domain::new().set_fqdn("example");
pub fn set_create_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of create_time.

Example
use wkt::Timestamp;
let x = Domain::new().set_create_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_create_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of create_time.

Example
use wkt::Timestamp;
let x = Domain::new().set_or_clear_create_time(Some(Timestamp::default()/* use setters */));
let x = Domain::new().set_or_clear_create_time(None::<Timestamp>);
pub fn set_update_time<T>(self, v: T) -> Self
where T: Into<Timestamp>,

Sets the value of update_time.

Example
use wkt::Timestamp;
let x = Domain::new().set_update_time(Timestamp::default()/* use setters */);
pub fn set_or_clear_update_time<T>(self, v: Option<T>) -> Self
where T: Into<Timestamp>,

Sets or clears the value of update_time.

Example
use wkt::Timestamp;
let x = Domain::new().set_or_clear_update_time(Some(Timestamp::default()/* use setters */));
let x = Domain::new().set_or_clear_update_time(None::<Timestamp>);
pub fn set_state<T: Into<State>>(self, v: T) -> Self

Sets the value of state.

Example
use google_cloud_managedidentities_v1::model::domain::State;
let x0 = Domain::new().set_state(State::Creating);
let x1 = Domain::new().set_state(State::Ready);
let x2 = Domain::new().set_state(State::Updating);
pub fn set_status_message<T: Into<String>>(self, v: T) -> Self

Sets the value of status_message.

Example
let x = Domain::new().set_status_message("example");
pub fn set_trusts<T, V>(self, v: T) -> Self
where T: IntoIterator<Item = V>, V: Into<Trust>,

Sets the value of trusts.

Example
use google_cloud_managedidentities_v1::model::Trust;
let x = Domain::new()
    .set_trusts([
        Trust::default()/* use setters */,
        Trust::default()/* use (different) setters */,
    ]);